#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package            : glabels
# homepage           : http://glabels.sourceforge.net/
# source location    : http://downloads.sourceforge.net/glabels/glabels-2.2.8.tar.gz
# dependency         : 

softname='glabels'
softversion='2.2.8'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/glabels/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
glabels: glabels - A program for creating labels and business cards
glabels:
glabels: It is designed to work with various laser/ink-jet peel-off label 
glabels: and business card sheets that you'll find at most office supply 
glabels: stores.
glabels:
glabels:
glabels:
glabels:
glabels:
glabels:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# log
(

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# update mime info
cat << "EOF" > $dest/install/doinst.sh
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
     usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
     usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
EOF

# fix desktop compliance
cd $dest/usr/share/icons/hicolor/48x48/apps
ln -s ../../../../pixmaps/glabels.png glabels.png

sed -i "s|glabels.png|glabels|g" $dest/usr/share/applications/glabels.desktop

# add 'default' files
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING COPYING-DOCS COPYING-LIBGLABELS COPYING.README_FIRST ChangeLog INSTALL NEWS README TODO \
      $dest/usr/doc/$softname-$softversion

#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "alsa-lib,atk,audiofile,avahi,cairo,dbus,dbus-glib,e2fsprogs,\
esound,evolution-data-server,evolution,expat,fontconfig,freetype,gcc,\
gconf,glib2,gnome-keyring,gnome-vfs,gnutls,gtk+2,krb5,libICE,\
libSM,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,\
libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,libart_lgpl,\
libbonobo,libbonoboui,libgcrypt,libglade,libgnome,libgnomecanvas,libgnomeui,\
libgpg-error,libpng,libsoup,libtasn,libxcb,libxml2,nss-nspr|sqlite,openssl,\
orbit2,pango,pixman,popt,sqlite,xcb-util,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/glabels/source/build-glabels.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
